unit ConvertUtil;

interface

uses
  SysUtils, Classes, Dialogs, VecMat3D;

var
    BodyList : TStringList;
    BodyNameList : TStringList;
    JointList : TStringList;
    bFrcList : TStringList;
    sfrcList : TStringList;
    GOList : TStringList;
    IdentList : TStringList;
    BodyIndex : array of integer;
    vArray : array of array of TVector3;
    rCenter : TVector3;
    rCurrent : TVector3;
    A0Body : TMatrix3;
    ftArray : array of String;
    frcGoIndex : integer;
    irJoints, ifJoints : integer;
    A0i : Array of TMatrix3;
    r0i : Array of TVector3;
    DirectImport : boolean;
    OutList : TStringList;

procedure InitData;
procedure FreeData;
procedure ReadIdentifiers(FileName : string);
function ReadBody(AName : string) : boolean;
function ReadForceTemplate(AName : string) : boolean;
procedure ReadElements(FileName : string);
procedure Clear;
function A01Body(index : integer) : TMatrix3;
Function r01Body(index : integer) : TVector3;
function BodyName(Index : integer) : string;
function BodyPoint(Index1, Index2 : integer) : TVector3;
function FrundToUM(const AName : string) : boolean;

implementation

function GetNumbers(s : string; var i1,i2 : integer) : boolean;
begin
  Result:=false;
  s:=trim(s);
  try
    i1:=StrToInt(Trim(copy(s,1,pos(' ',s))));
  except
    exit;
  end;
  try
    i2:=StrToInt(Trim(copy(s,pos(' ',s), Length(s)-pos(' ',s)+1)));
  except
    exit;
  end;
  Result:=true;
end;

function FrundToUM(const AName: string) : boolean;
var List : TStringList;
    i : integer;
    s, s1 : string;
    i1,i2 : integer;
begin
  Clear;
  Result:=true;
  List := TStringList.Create;
  List.LoadFromFile(AName);
  SetLength(BodyIndex,0);
  OutList.add('with main; version=40 ;');
  OutList.add('  type=mbs;  autogravity=true;  eqn_ok=true; generation = direct; language=pascal; size=1; scene=0; bkgcolor=0; ');
  for i:=0 to List.Count-1 do begin
    s:=List[i];
    if Trim(s)<>'' then begin
      if not GetNumbers(s,i1,i2) then ShowMessage('  "'+aName+'",  '+s);
      s:=ExtractFilePath(AName)+'\'+IntToStr(i2)+'.elf';
      if Not FileExists(s) then begin
        ShowMessage('File not found "'+ s+'"');
        Break;
      end;
      case i1 of
      2 : ReadForceTemplate(s);
      end;
    end;
  end;
  for i:=0 to List.Count-1 do begin
    s:=List[i];
    if Trim(s)<>'' then begin
      if not GetNumbers(s,i1,i2) then ShowMessage('  "'+aName+'",  '+s);
      s:=ExtractFilePath(AName)+'\'+IntToStr(i2)+'.elf';
      if Not FileExists(s) then begin
        ShowMessage('File not found "'+ s+'"');
      end;
      case i1 of
      1 : ReadBody(s);
      3 : ReadIdentifiers(s);
      2 : begin
//          ReadForceTemplate(s);
          if frcGoIndex=-1 then begin
            frcGoIndex:=BodyNameList.Count+1;
            goList.Add('with go; name="GO1";');
            goList.Add('  with ge; type= CYLINDER;');
            goList.Add('  VisibleSide=vsFront;  material=14540253,16777215,0,0,10,1;');

            goList.Add('  width=1;');
            goList.Add('  h=1; r1=0.02; r2=0.02;');
            goList.Add('  npc=15; npl=2;');
            goList.Add('  with ge; type= SPRING;');
            goList.Add('  VisibleSide=vsFront;  material=8421504,16777215,0,0,10,1;');
            goList.Add('  wired=true;');
            goList.Add('  width=2;');
            goList.Add('  SolidType=Wired;');
            goList.Add('  h=1; r=0.1; n=10; np=15;');
          end;
        end;
      4 : ;
      5 : ReadElements(s);
      6 :;
      7 :;
      end;
    end;
  end;
  List.Free;
  for i:=0 to IdentList.Count-1 do
    OutList.Add(IdentList[i]);
  OutList.add('with egravity; gravityz=-1.0;');
  for i:=0 to GOList.Count-1 do
    OutList.Add(GoList[i]);
  for i:=0 to BodyList.Count-1 do
    OutList.Add(BodyList[i]);
  for i:=0 to JointList.Count-1 do
    OutList.Add(JointList[i]);
  for i:=0 to bFrcList.Count-1 do
    OutList.Add(bFrcList[i]);
  for i:=0 to sFrcList.Count-1 do
    OutList.Add(sFrcList[i]);
  OutList.Add('with end;');
  if not DirectImport then
    OutList.SaveToFile(ExtractFilePath(AName)+'\input.dat')
end;

procedure InitData;
begin
  OutList := TStringList.Create;
  BodyList := TStringList.Create;
  JointList := TStringList.Create;
  GOList := TStringList.Create;
  bFrcList := TStringList.Create;
  BodyNameList := TStringList.Create;
  IdentList := TStringList.Create;
  sFrcList := TStringList.Create;
  DirectImport:=false;
  frcGoIndex:=-1;
end;

procedure FreeData;
begin
  OutList.Free;
  BodyList.Free;
  JointList.Free;
  GOList.Free;
  bFrcList.Free;
  BodyNameList.Free;
  IdentList.Free;
  sFrcList.Free;
end;

function ReadBody(AName: string) : boolean;
var List : TStringList;
    bName : string;
    i,nVert : integer;
    gFile : System.text;
    i1, i2, i3, i4 : integer;
    xo,yo,zo : double;
    A01 : Tmatrix3;
    hA : Tmatrix3;
    e, e1, e2 : TVector3;
    r : double;
    WasFace : boolean;

  procedure ReadGraphics(Index : integer);
  var i : integer;
      iBody : integer;
  begin
    System.assign(gFile,AName); Reset(gFile);
    ReadLn(gFile,nVert);
    if Index=1 then begin
      Golist.Add('with go; name="'+bName+'";');
      Golist.Add('  with ge; type= POLYGON; width=1;');
      Golist.Add('    Vertices = {');
    end;
    if index=0 then SetLength(vArray, Length(BodyIndex));
    if index=0 then SetLength(A0i, Length(BodyIndex));
    if index=0 then SetLength(r0i, Length(BodyIndex));
    iBody:=High(vArray);
    if index=0 then SetLength(vArray[iBody], nvert);
    for i:=1 to nvert do begin
      if Index=1 then begin
        ReadLn(gFile,xo,yo,zo);
        Golist.Add('    '+FloatToStr(vArray[iBody][i-1]._[1])+','+
          FloatToStr(vArray[iBody][i-1]._[2])+','+FloatToStr(vArray[iBody][i-1]._[3])+';');
      end else
        ReadLn(gFile,vArray[iBody][i-1]._[1],vArray[iBody][i-1]._[2],vArray[iBody][i-1]._[3]);
    end;
    if Index=1 then begin
      Golist.Add('    };');
      Golist.Add('    Faces = {');
      WasFace:=true;
    end;
    while not EOF(gFile) do begin
      Read(gFile,i1);
      Case i1 of
      2 : begin
          WasFace:=true;
          ReadLn(gFile,i2, i3, i4);
          if Index=1 then
            Golist.Add('    0,'+IntToStr(i2)+','+IntToStr(i3)+';');
        end;
      100 : begin // 
          if (Index=1) and WasFace then  begin Golist.Add('    };'); WasFace:=false; end;
          ReadLn(gFile,i2);
          if Index=0 then rCenter:=vArray[iBody][i2-1].mul_r(1/1000)^;
          if Index=1 then
        end;
      30 : begin //    
          if (Index=1) and WasFace then  begin Golist.Add('    };'); WasFace:=false; end;
          readln(gFile, rCurrent._[1], rCurrent._[2],rCurrent._[3]);
          R0i[High(R0i)]:=rCurrent;
          readln(gFile, A0Body._[1,1],A0Body._[2,1],A0Body._[3,1],
                        A0Body._[1,2],A0Body._[2,2],A0Body._[3,2],
                        A0Body._[1,3],A0Body._[2,3],A0Body._[3,3]);
          if Index=1 then begin
            JointList.Add('with joint; name="j'+bName+'"; type=comm; bd1="Base0"; bd2="'+
              bName+'"; weight=1000;');
            JointList.Add('  with et; type=tc; ex='+FloatToStr(rCurrent._[1])+';'+
                                             ' ey='+FloatToStr(rCurrent._[2])+';'+
                                             ' ez='+FloatToStr(rCurrent._[3])+';');
            A0Body.GetAngles(1,xo, yo, zo);
            A0i[High(A0i)]:=A0Body;
            JointList.Add('  with et; type=tv; ex= 1.0;');
            JointList.Add('  with et; type=tv; ey= 1.0;');
            JointList.Add('  with et; type=tv; ez= 1.0;');
            JointList.Add('  with et; type=rv; ex= 1.0;');
            JointList.Add('  with et; type=rv; ey= 1.0;');
            JointList.Add('  with et; type=rv; ez= 1.0;');
            JointList.Add('  with et; type=rc; ex= 1.0; coord0='+FloatToStr(xo*180/pi)+';');
            JointList.Add('  with et; type=rc; ey= 1.0; coord0='+FloatToStr(yo*180/pi)+';');
            JointList.Add('  with et; type=rc; ez= 1.0; coord0='+FloatToStr(zo*180/pi)+';');
          end;
        end;
      60 : begin
           Readln(gFile);
           if (Index=1) and WasFace then  begin Golist.Add('    };'); WasFace:=false; end;
         end;
      3 : begin
          if (Index=1) and WasFace then  begin Golist.Add('    };'); WasFace:=false; end;
          ReadLn(gFile,i2, i3, xo, i4);
          if (Index=1) then begin
            GOList.Add('  with ge; type= ELLIPSE; width=1;');
            GoList.Add('  ro1x='+FloatToStr(vArray[iBody][i3-1]._[1])+
                       '; ro1y='+FloatToStr(vArray[iBody][i3-1]._[2])+
                       '; ro1z='+FloatToStr(vArray[iBody][i3-1]._[3])+';');
            case i2 of
            2 : GoList.Add('  axis1=2; angle1=90;');
            3 : GoList.Add('  axis1=1; angle1=90;');
            end;
            GOList.Add('    a='+FloatToStr(xo/1000)+'; b='+FloatToStr(xo/1000)+
              ';n='+ IntToStr(i4) + '; fill=no;');
          end;
        end;
      4,5 : begin
          if (Index=1) and WasFace then  begin Golist.Add('    };'); WasFace:=false; end;
          ReadLn(gFile,i2, i3, r, i4);
          e2.Init(vArray[iBody][i3-1]._[1]-vArray[iBody][i2-1]._[1], vArray[iBody][i3-1]._[2]-vArray[iBody][i2-1]._[2],
            vArray[iBody][i3-1]._[3]-vArray[iBody][i2-1]._[3]).Normalize;
          e.Init(1,0,0); e1.Init(0,1,0);
          e.is_x(e,e1);
          if e.abs<0.01 then e.is_x(e,e2);
          e.Normalize;
          e1.is_x(e2,e);
          hA._[1]:=e._;
          hA._[2]:=e1._;
          hA._[3]:=e2._;
          hA:=hA.T^;
          hA.GetAngles(1,xo, yo, zo);
          if (Index=1) then begin
            GOList.Add('  with ge; type= ELLIPSE; width=1;');
            GoList.Add('  ro1x='+FloatToStr(vArray[iBody][i2-1]._[1])+
                         '; ro1y='+FloatToStr(vArray[iBody][i2-1]._[2])+
                         '; ro1z='+FloatToStr(vArray[iBody][i2-1]._[3])+';');
            GoList.Add('  axis1=1; angle1='+FloatToStr(xo*180/pi)+';');
            GoList.Add('  axis2=2; angle2='+FloatToStr(yo*180/pi)+';');
            GoList.Add('  axis3=3; angle3='+FloatToStr(zo*180/pi)+';');
            GOList.Add('    a='+FloatToStr(r/1000)+'; b='+FloatToStr(r/1000)+
              '; n='+ IntToStr(i4) + '; fill=no;');
          end;
        end;
      999 : begin
          if (Index=1) and WasFace then  begin Golist.Add('    };'); WasFace:=false; end;
          break;
        end;
      end;
    end;
    System.Close(gFile);
    if Index=0 then
      for i:=0 to Length(vArray[iBody])-1 do
        vArray[iBody][i].is_sub(vArray[iBody][i].mul_r(1/1000)^,rCenter);
  end;

begin
  SetLength(BodyIndex,Length(BodyIndex)+1);
  List := TStringList.Create;
  List.LoadFromFile(AName);
  bName:=List[0];
  BodyNameList.Add(bName);
  BodyList.Add('with body; name="'+List[0]+'"; igrobj='+IntToStr(Length(BodyIndex))+';'); //     
  BodyList.Add('  m='+List[8]+'; ixx='+List[9]+'; iyy='+List[10]+'; izz='+List[11]+';');
  List[17]:=Trim(List[17]);
  BodyIndex[High(BodyIndex)]:=StrToInt(Trim(Copy(List[17],1,Pos(' ',List[17]))));
  List.Clear;
  AName[Length(AName)]:='g';
  if Not FileExists(AName) then ShowMessage('Geometry file not found "'+AName+'"')
  else begin
    ReadGraphics(0);
    ReadGraphics(1);
  end;
end;

procedure Clear;
begin
  OutList.Clear;
  BodyList.Clear;
  JointList.Clear;
  GOList.Clear;
  SetLength(ftArray,0);
  BodyNameList.Clear;
  bFrcList.Clear;
  IdentList.Clear;
  sFrcList.Clear;
  SetLength(A0i,0);
  SetLength(r0i,0);
  frcGoIndex:=-1;
end;

function ReadForceTemplate(AName: string): boolean;
var List : TStringList;
    Index : integer;
begin
  if FileExists(AName) then begin
    List := TStringList.Create;
    List.LoadFromFile(AName);
    Index:=StrToInt(List[1]);
    if Length(ftArray)<=Index-1 then SetLength(ftArray, Index);
    ftArray[Index-1]:=aName;
    List.Free;
  end;
end;

procedure ReadElements(FileName: string);
type TElementType = (etNoType, etJoint, etBfrc);
     TBodyRef = (brBase0, brFirstBody);
var Index : integer;
    AName : string;
    gFile : System.text;
    iBody1, iBody2, iNode1, iNode2 : integer;
    i,j : integer;
    iFT : integer;
    r1, r2 : TVector3;
    ElementAxisType : array[1..6] of integer;
    ElementType : TElementType;
    ElementKey : integer;
    ElementLength : double;
    sElementLength : string;
    BodyRef : TBodyRef;
    JointStiffness, JointDamping : array[1..6] of string;

  function IsZero(s : string) : boolean;
  var r : double;
      code : integer;
  begin
    val(s,r,code);
    if Code<>0 then begin
//      ShowMessage('Itentifier found: '+s);
    end;
    Result:=((Code=0) and (r=0));
  end;

  procedure Create6DOFJointFirstBody;
  begin
    JointList.Add('with joint1; type=6dof; name="'+aName+'"; bd1="'+BodyName(iBody1)+
      '"; bd2="'+BodyName(iBody2)+'";');
    JointList.Add('  with jnt6dof;');
    JointList.Add('  ro1x='+FloatToStr(r1._[1])+';'+
                 '  ro1y='+FloatToStr(r1._[2])+';'+
                 '  ro1z='+FloatToStr(r1._[3])+';');
    JointList.Add('  ro2x='+FloatToStr(r2._[1])+';'+
                  '  ro2y='+FloatToStr(r2._[2])+';'+
                  '  ro2z='+FloatToStr(r2._[3])+';');
    JointList.Add('  angles=Cardan(123);');
    if ElementAxisType[1]=0 then JointList.Add('  x0=0;');
    if ElementAxisType[2]=0 then JointList.Add('  y0=0;');
    if ElementAxisType[3]=0 then JointList.Add('  z0=0;');
    if ElementAxisType[4]=0 then JointList.Add('  angle1=0;');
    if ElementAxisType[5]=0 then JointList.Add('  angle2=0;');
    if ElementAxisType[6]=0 then JointList.Add('  angle3=0;');
  end;

  procedure CreateCompiantJointFirstBody;

    procedure AddJointForce(Index : integer);
    begin
      JointList.Add('  with frclist;');
      JointList.Add('  with sbfrc; name="sbFrc1"; type=linear; argument=x;');
      JointList.Add('   k='+JointStiffness[Index]+';');
      JointList.Add('  with sbfrc; name="sbFrc2"; type=linear; argument=v;');
      JointList.Add('   k='+JointDamping[Index]+';');
    end;

    function GetType(Index : integer) : string;
    begin
      case index of
      1 : Result:='tv; ex';
      2 : Result:='tv; ey';
      3 : Result:='tv; ez';
      4 : Result:='rv; ex';
      5 : Result:='rv; ey';
      6 : Result:='rv; ez';
      end;
    end;


  var i : integer;
      A12 : TMatrix3;
      a1, a2, a3 : double;
      r12 : TVector3;
  begin
    JointList.Add('with joint1; type=comm; name="'+aName+'"; bd1="'+BodyName(iBody1)+
      '"; bd2="'+BodyName(iBody2)+'";');
    JointList.Add('  with et; type=tc; ex='+FloatToStr(r1._[1])+';'+
                                     ' ey='+FloatToStr(r1._[2])+';'+
                                     ' ez='+FloatToStr(r1._[3])+';');
    for i:=1 to 6 do
      if ElementAxisType[i]=0 then begin
        JointList.Add('  with et; type='+GetType(i)+'= 1.0;');
      end else
        if (ElementAxisType[i]=15) and not IsZero(JointStiffness[i]) then begin
          JointList.Add('  with et; type='+GetType(i)+'= 1.0; jfrctype=frclist;');
          AddJointForce(i);
        end;
    r12.is_sub(r01Body(ibody2),r01Body(ibody1));
    r12:=A01Body(ibody1).mul_v(r12,true)^;
    A12.is_mul(A01Body(ibody1).T^,A01Body(ibody2));
    A12.GetAngles(1,a1, a2, a3);
    JointList.Add('  with et; type=rc; ex= 1.0; coord0='+FloatToStr(a1*180/pi)+';');
    JointList.Add('  with et; type=rc; ey= 1.0; coord0='+FloatToStr(a2*180/pi)+';');
    JointList.Add('  with et; type=rc; ez= 1.0; coord0='+FloatToStr(a3*180/pi)+';');

    JointList.Add('  with et; type=tc; ex='+FloatToStr(-r2._[1])+';'+
                                     ' ey='+FloatToStr(-r2._[2])+';'+
                                     ' ez='+FloatToStr(-r2._[3])+';');
  end;


  procedure ReadJoint;
  var npar, i, j  : integer;
      CompliantJoint : boolean;
  begin
    CompliantJoint:=false;
    for i:=1 to 6 do begin
      if ElementAxisType[i]<>15 then continue;
      Readln(gFile, j, nPar);
      if nPar = 3 then BodyRef:=brBase0 else BodyRef:=brFirstBody;
      Readln(gFile, JointStiffness[i]);
      if not CompliantJoint then
        CompliantJoint:=not IsZero(JointStiffness[i]);
      for j:=2 to nPar do Readln(gFile);
      Readln(gFile, j, nPar);
      Readln(gFile, JointDamping[i]);
      for j:=2 to nPar do Readln(gFile);
    end;
    if CompliantJoint then begin
      case BodyRef of
      brBase0  : begin
        ShowMessage('Joint in Base0')
        end;
      brFirstBody : CreateCompiantJointFirstBody;
      end;
    end else begin
      case BodyRef of
      brBase0  : begin
        ShowMessage('Joint in Base0')
        end;
      brFirstBody : CreateCompiantJointFirstBody;//Create6DOFJointFirstBody;
      end;
    end;
  end;

  procedure ReadBFrc;
  var npar, i, j  : integer;
      Stiffness, Damping : string;
      P : array[1..50] of string;
      xStar : string;
  begin
    BfrcList.Add('with bfrc; name="'+aName+'"; type=frclist; bd1="'+BodyName(iBody1)+
      '"; bd2="'+BodyName(iBody2)+'";igrobj='+IntToStr(frcGoIndex)+';');
    BfrcList.Add('  ro1x='+FloatToStr(r1._[1])+';'+
                 '  ro1y='+FloatToStr(r1._[2])+';'+
                 '  ro1z='+FloatToStr(r1._[3])+';');
    BfrcList.Add('  ro2x='+FloatToStr(r2._[1])+';'+
                 '  ro2y='+FloatToStr(r2._[2])+';'+
                 '  ro2z='+FloatToStr(r2._[3])+';');
    BfrcList.Add('  with frclist;');
    BfrcList.Add('  with sbfrc; name="sbFrc1";');
    Readln(gFile, i, nPar);
    xStar:='';
    case i of
    1 : begin //Linear stiffness
        Readln(gFile, Stiffness);
        BfrcList.Add('   type=linear; leveltype =0; argument=x;');
        BfrcList.Add('   k='+Stiffness+';'+'l0='+sElementLength+';');
      end;
    3 : begin
         BfrcList.Add('   type=points_s; argument=x; comments="-    ";');
         BfrcList.Add('   points={');
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('    '''+sElementLength+'-('+P[5]+'+0.01)'' ''('+P[5]+')*('+P[2]+')+('+P[3]+')*0.01''  ''''');
         BfrcList.Add('    ''-('+P[5]+')+'+sElementLength+''' ''('+P[5]+')*('+P[2]+')''  ''''');
         BfrcList.Add('    ''-('+P[4]+')+'+sElementLength+''' ''('+P[4]+')*('+P[2]+')''  ''''');
         BfrcList.Add('    '''+sElementLength+'-('+P[4]+'-0.01)'' ''-('+P[2]+')*('+P[4]+')-('+P[1]+')*0.01''  ''''');
         BfrcList.Add('   };');
      end;
    8 : begin
         for i:=1 to nPar do Readln(gFile, P[i]);
         xStar:='(-('+P[2]+')+('+sElementLength+'))';
         BfrcList.Add('   type=expression; comments="  ";');
         BfrcList.Add('   expression=-heavi(x-'+xStar+')*'+P[1]+'*(x-'+xStar+');');
(*         BfrcList.Add('   points={');
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('    ''-('+P[2]+')+0.01'+sElementLength+''' ''('+P[1]+')*0.01''  ''''');
         BfrcList.Add('    ''-('+P[2]+')+'+sElementLength+''' ''0''  ''''');
         BfrcList.Add('    ''0'' ''0''  ''''');
         BfrcList.Add('   };');*)
      end;
    10 : begin
         BfrcList.Add('   type=points_s; argument=x; comments="-    ";');
         BfrcList.Add('   points={');
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('    ''-('+P[4]+')+'+sElementLength+FloatToStr(-0.01)+''' ''('+P[1]+')*('+P[4]+')+('+P[2]+')*0.01''  ''''');
         BfrcList.Add('    ''-('+P[4]+')+'+sElementLength+''' ''('+P[1]+')*('+P[4]+')''  ''''');
         BfrcList.Add('    ''-('+P[3]+')/('+P[1]+')+'+sElementLength+''' '''+P[3]+'''  ''''');
         BfrcList.Add('    '''+sElementLength+'-('+P[3]+')/('+P[1]+')*10'' '''+P[3]+'''  ''''');
         BfrcList.Add('   };');
      end;
    14 : begin
         for i:=1 to nPar do Readln(gFile, P[i]);
         xStar:='(-x+('+sElementLength+'))';
         BfrcList.Add('   type=expression; comments="";');
         BfrcList.Add('   expression=-('+P[2]+')*('+P[3]+')*(('+P[1]+')/(('+P[1]+'+'+xStar+'*('+P[3]+'))))^('+P[4]+');');
      end;
    50 : begin
         BfrcList.Add('   type=points_s; argument=x; comments="-    ";');
         BfrcList.Add('   points={');
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('    '''+sElementLength+'-('+P[5]+'+0.1)'' ''('+P[5]+')*('+P[2]+')+('+P[3]+')*0.1''  ''''');
         BfrcList.Add('    ''-('+P[5]+')+'+sElementLength+''' ''('+P[5]+')*('+P[2]+')''  ''''');
         BfrcList.Add('    ''-('+P[4]+')+'+sElementLength+''' ''('+P[4]+')*('+P[2]+')''  ''''');
         BfrcList.Add('    '''+sElementLength+''' ''-('+P[2]+')*('+P[4]+')-('+P[1]+')*('+P[4]+')''  ''''');
         BfrcList.Add('   };');
      end;
    else begin
        ShowMessage('Unknown bfrc positioning type'+ftArray[iFT-1]+' '+IntToStr(i));
        Exit;
      end;
    end;

    Readln(gFile, i, nPar);
    BfrcList.Add('  with sbfrc; name="sbFrc2";');
    case i of
    50 : begin //Linear stiffness
        Readln(gFile, Damping);
        BfrcList.Add('   type=linear; leveltype =0; argument=v;');
        BfrcList.Add('   k='+Damping+';'+'l0=0;');
      end;
    55 : begin
         BfrcList.Add('   type=points_s; argument=v; comments="    ";');
         BfrcList.Add('   points={');
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('    ''-('+P[6]+'+0.01)'' ''('+P[6]+')*('+P[3]+')+('+P[4]+')*0.01''  ''''');
         BfrcList.Add('    ''-('+P[6]+')'' ''('+P[6]+')*('+P[3]+')''  ''''');
         BfrcList.Add('    ''0'' ''0''  ''''');
         BfrcList.Add('    ''-('+P[5]+')'' ''('+P[5]+')*('+P[2]+')''  ''''');
         BfrcList.Add('    ''-('+P[5]+'-0.01)'' ''('+P[2]+')*('+P[5]+')-('+P[1]+')*0.01''  ''''');
         BfrcList.Add('   };');
      end;
    58 : begin
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('   type=expression; comments="  ";');
         BfrcList.Add('   expression=-heavi(x-('+P[2]+'))*'+P[1]+'*v;');
      end;
    53 : begin
         BfrcList.Add('   type=points_s; argument=v; comments="     ";');
         BfrcList.Add('   points={');
         for i:=1 to nPar do Readln(gFile, P[i]);
         BfrcList.Add('    ''-('+P[2]+'+0.2)'' ''+('+P[2]+')*('+P[1]+')''  ''''');
         BfrcList.Add('    ''-('+P[2]+')'' ''+('+P[2]+')*('+P[1]+')''  ''''');
         BfrcList.Add('    ''+('+P[2]+')'' ''-('+P[2]+')*('+P[1]+')''  ''''');
         BfrcList.Add('    ''+('+P[2]+'+0.2)'' ''-('+P[2]+')*('+P[1]+')''  ''''');
         BfrcList.Add('   };');
      end;
    else begin
        ShowMessage('Unknown bfrc damping type' + ftArray[iFT-1]+' '+IntToStr(i));
        exit;
      end;
    end;
  end;

var s : string;

  procedure ReadOtherFrc;
  var i, j  : integer;
      s, Comment : string;
  begin
    Comment:=AName +'-->';
    for i:=1 to 6 do
      Comment:=Comment+IntToStr(ElementAxisType[i])+'; ';
    while not eof(gFile) do begin
      Readln(gFile, s);
      Comment:=Comment+'(*'+s+'*)';
    end;
    sfrcList.Add('with sfrc; name="'+aName+'"; type=spring; bd1="'+BodyName(iBody1)+
      '"; bd2="'+BodyName(iBody2)+'"; comments="'+Comment+'";');
    sfrcList.Add('  ro1x='+FloatToStr(r1._[1])+';'+
                 '  ro1y='+FloatToStr(r1._[2])+';'+
                 '  ro1z='+FloatToStr(r1._[3])+';');
    sfrcList.Add('  ro2x='+FloatToStr(r2._[1])+';'+
                  '  ro2y='+FloatToStr(r2._[2])+';'+
                  '  ro2z='+FloatToStr(r2._[3])+';');
  end;

begin
  if FileExists(FileName) then begin
    System.assign(gFile,FileName); Reset(gFile);
    ReadLn(gFile,aName);
    ReadLn(gFile);
    Read(gFile,iBody1, i, iNode1);
    ReadLn(gFile);
    Read(gFile,iBody2, i, iNode2);
    ReadLn(gFile);
    Read(gFile,iFT);
    readln(gFile, ElementKey, ElementLength);
    readln(gFile, sElementLength);
    System.Close(gFile);
    r1:=BodyPoint(iBody1, iNode1);
    r2:=BodyPoint(iBody2, iNode2);
    System.assign(gFile,ftArray[iFT-1]); Reset(gFile);
    ReadLn(gFile,s);
    ReadLn(gFile,s);

    for i:=1 to 6 do Readln(gFile, ElementAxisType[i]);
    ElementType:=etNoType;
    if ElementKey=1 then ElementType:=etBfrc else
    for i:=1 to 6 do
      if ElementAxisType[i]=15 then begin
        ElementType:=etJoint;
        Break;
      end;
    if ElementType=etNoType then begin
//      ShowMessage('Unknown element type ' + aName);
    end;
    case ElementType of
    etJoint : ReadJoint;
    etBfrc : ReadBFrc;
    etNoType : ReadOtherFrc;
    end;

    System.Close(gFile);
  end;
end;

function BodyName(Index: integer): string;
var i : integer;
begin
  Result:='';
  for i:=0 to length(BodyIndex)-1 do
    if BodyIndex[i]=Index then begin
      Result:=BodyNameList[i];
      Break;
    end;
end;

function BodyPoint(Index1, Index2 : integer): TVector3;
var i : integer;
begin
  Result.is_0;
  for i:=0 to length(BodyIndex)-1 do
    if BodyIndex[i]=Index1 then break;
  if i<length(BodyIndex) then begin
    Result:=vArray[i][Index2-1];
  end;
end;

procedure ReadIdentifiers(FileName : string);
var tFile : System.Text;
    nIdents, i : integer;
    iName, iValue, iComment : string;
begin
  System.assign(tFile,FileName); Reset(tFile);
  ReadLn(tFile); ReadLn(tFile);
  Read(tFile, nIdents); ReadLn(tFile);
  IdentList.Add('with const;');
  for i:=1 to nIdents do begin
    readln(tFile, iName);
    readln(tFile, iValue);
    readln(tFile,  iComment);
    if iComment='?' then iComment:='';
    IdentList.Add('  cnst=('+iName+','+iValue+',"'+iComment+'");');
  end;
  System.Close(tFile)
end;

function A01Body(index: integer): TMatrix3;
var i : integer;
begin
  Result.is_E;
  for i:=0 to length(BodyIndex)-1 do
    if BodyIndex[i]=Index then break;
  if i<length(BodyIndex) then begin
    Result:=A0i[i];
  end;
end;

function r01Body(index: integer): TVector3;
var i : integer;
begin
  Result.is_0;
  for i:=0 to length(BodyIndex)-1 do
    if BodyIndex[i]=Index then break;
  if i<length(BodyIndex) then begin
    Result:=r0i[i];
  end;
end;

end.

